A constructor for the eCAR class. The class eCAR is a named list containing
the output from the calling the par.eCAR.Leroux or semipar.eCAR.Leroux functions.
eCAR.out(
data_model = NULL,
beta_omega = NULL,
posterior_draws = NULL,
DIC = NULL,
regrcoef = NULL
)a characther indicating what data model was fit;
matrix containing estimated beta as a function of omega with 95% credible bands, and eigen-values;
a list containing the posterior draws of all model parameters;
Deviance information criterion;
posterior summaries (mean, sd, 0.025quant, 0.975quant) for the regression coefs;