A list containing the data frame and neighborhood matrix based on 56 districts of Scotland that is with the following variables
lipcancerdata: A data frame with 56 rows and the following 6 variables:
observed number of cancer cases
the expected number of lip cancer cases computed using indirect standardisation based on Scotland-wide disease rates
percentage of the district’s workforce employed in agriculture, fishing and forestry
latitude coordinates
longitude coordinates
name
neighborhood.Matrix: A 56 x 56 matrix neighbhorhood matrix