- y
response vector
- x
covariate vector for which casual effect is desired
- W
neighborhood matrix comprised of zeros and ones
- E
Offset value whose specification depends on the data model selected such that for
* Poisson - E is vector that contains expected counts
* Binomial - E is vector that contains number of trials
* Negative Binomial - E is vector that contains an offset.
- C
design matrix for the covariates that are included as controls
- names.covariates
Specifies the names of the covariates inside C
- model
Specifies the likelihood or data model. Options are "Gaussian", "Poisson", "Binomial", "Negative Binomial"
- L
Number of basis functions for the spline model on the (spatial scale)-varying beta. The smoothing method applied here is a Bayesian version of the P-spline approach by Eilers and Marx (1996), assuming a random walk on the spline coefficients and a PC-prior on the precision parameter of the random walk.
- pcprior.sd
Vector of length 2 specifying the scaling parameters for the PC-priors assumed on the precision of the (spatial scale)-varying beta and the data y, respectively. Each of the scaling parameters can be interpreted as a guess on the marginal standard deviation (default are 0.1 and 1).
- s2
Prior variance for the log of the dispersion parameter (only used for model="Negative Binomial", default equal to 10).
- method
A character defining the type of adjustment; either "spectral" (default choice) which implements the model assuming (spatial scale)-varying beta, or "naive" which implements the standard method with constant beta hence no spectral adjustment.
- verbose
logical; if TRUE the verbose output from the "inla" call is printed.
- num.threads.inla
Argument that indicates the number of computing cores that the INLA call will occupy. For syntax, see ``inla.setOption"
- ...
Arguments to be passed to the "inla" call; for instance control.inla=list(strategy="laplace")